CloudFile class

A file from a cloud storage provider.

Constructors

CloudFile({required String id, required String name, String? mimeType, int? size, String? parentId, String? thumbnailUrl, required String createdAt, required String modifiedAt})
const
CloudFile.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
mimeType String?
final
modifiedAt String
final
name String
final
parentId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final
thumbnailUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited