FirestackChannel class

Firestack messaging channel model.

Constructors

FirestackChannel({required String id, required String name, required String slug, String? description, required String type, String? avatar, required bool isPrivate, required bool isArchived, Map<String, dynamic>? metadata, int? membersCount, int? unreadCount, FirestackChannelMessage? lastMessage, String? lastMessageAt, required String createdAt, required String updatedAt})
const
FirestackChannel.fromJson(Map<String, dynamic> json)
factory

Properties

avatar String?
final
createdAt String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isArchived bool
final
isDirect bool
no setter
isGroup bool
no setter
isPrivate bool
final
lastMessage FirestackChannelMessage?
final
lastMessageAt String?
final
membersCount int?
final
metadata Map<String, dynamic>?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
final
type String
final
unreadCount int?
final
updatedAt String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited