FirestackEmailTemplates class

Firestack email template API for app users.

Constructors

FirestackEmailTemplates({required FirestackClient client})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required String name, required String key, required String subject, String? bodyHtml, String? bodyText, List<String>? variables}) Future<Map<String, dynamic>>
Create a new email template.
delete(String templateId) Future<void>
Delete an email template.
get(String templateId) Future<Map<String, dynamic>>
Get a single email template.
list({int perPage = 15, int page = 1}) Future<PaginatedResult<Map<String, dynamic>>>
List email templates for the current project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preview({required String templateId, Map<String, dynamic>? variables}) Future<Map<String, dynamic>>
Preview a rendered email template.
send({required String templateId, required String to, Map<String, dynamic>? variables}) Future<Map<String, dynamic>>
Send an email using a template.
toString() String
A string representation of this object.
inherited
update(String templateId, {String? name, String? subject, String? bodyHtml, String? bodyText, List<String>? variables, bool? isActive}) Future<Map<String, dynamic>>
Update an email template.

Operators

operator ==(Object other) bool
The equality operator.
inherited