RemoteConfigFetchStatus enum

The status of the last remote config fetch.

Inheritance
Available extensions

Values

noFetchYet → const RemoteConfigFetchStatus

No fetch has been performed yet.

success → const RemoteConfigFetchStatus

The last fetch completed successfully.

failure → const RemoteConfigFetchStatus

The last fetch failed.

throttled → const RemoteConfigFetchStatus

The cached values are within the minimum fetch interval (throttled).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RemoteConfigFetchStatus>
A constant List of the values in this enum, in order of their declaration.