FirestackCloudStorage class
Firestack Cloud Storage API for third-party integrations.
Constructors
- FirestackCloudStorage(FirestackClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
{required CloudProvider provider, required String code, required String redirectUri, String? clientId, String? clientSecret}) → Future< CloudStorageProvider> - Connect a cloud storage provider after OAuth callback.
-
disconnect(
CloudProvider provider) → Future< void> - Disconnect a cloud storage provider.
-
getAuthUrl(
{required CloudProvider provider, required String redirectUri, String? clientId, String? clientSecret}) → Future< String> - Get an OAuth authorization URL for connecting a provider.
-
getDownloadUrl(
{required CloudProvider provider, required String fileId, int minutes = 60}) → Future< String> - Get a download URL for a cloud file.
-
listFiles(
{required CloudProvider provider, String? folderId, int limit = 50}) → Future< List< CloudFile> > - List files from a connected cloud provider.
-
listProviders(
) → Future< List< CloudStorageProvider> > - List all connected cloud storage providers for the project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadFile(
{required CloudProvider provider, required String filePath, required Uint8List fileBytes, String? folderId}) → Future< CloudFile> - Upload a file to a cloud provider.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited