SmtpConfig class
SMTP configuration for a project.
Constructors
- SmtpConfig({required int id, required String name, String? type, required String host, required String port, String? username, String? password, required String encryption, required String fromAddress, String? fromName, required bool isDefault, String? appUserUuid, required String createdAt, required String updatedAt})
-
const
-
SmtpConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appUserUuid → String?
-
final
- createdAt → String
-
final
- encryption → String
-
final
- fromAddress → String
-
final
- fromName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- id → int
-
final
- isDefault → bool
-
final
-
final
- name → String
-
final
- password → String?
-
final
- port → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
- updatedAt → String
-
final
- username → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited